==> pytroll_runner-0.2.0.tar.gz: pytroll_runner-0.2.0/CHANGELOG.md <==
## Version 0.2.0 (2025/04/28)


### Pull Requests Merged

#### Bugs fixed

* [PR 34](https://github.com/pytroll/pytroll-runner/pull/34) - Fix the bug #25 that a message is sent even when there is no match for the given regex
* [PR 33](https://github.com/pytroll/pytroll-runner/pull/33) - Support stderr

#### Features added

* [PR 31](https://github.com/pytroll/pytroll-runner/pull/31) - Allow passing metadata to the script
* [PR 29](https://github.com/pytroll/pytroll-runner/pull/29) - Migrate ci to newer python

In this release 4 pull requests were closed.


## Version 0.1.0 (2024/11/13)


### Pull Requests Merged

#### Features added

* [PR 19](https://github.com/pytroll/pytroll-runner/pull/19) - Add multiple threads capability
* [PR 8](https://github.com/pytroll/pytroll-runner/pull/8) - Add possibility to pass a message file
* [PR 7](https://github.com/pytroll/pytroll-runner/pull/7) - [pre-commit.ci] pre-commit autoupdate

In this release 3 pull requests were closed.


## Version 0.0.3 (2024/01/31)


### Pull Requests Merged

#### Bugs fixed

* [PR 5](https://github.com/pytroll/pytroll-runner/pull/5) - Fix starting publisher
* [PR 4](https://github.com/pytroll/pytroll-runner/pull/4) - Do not require "expected_files"
* [PR 3](https://github.com/pytroll/pytroll-runner/pull/3) - Fix premature closing of the subscriber

#### Features added

* [PR 1](https://github.com/pytroll/pytroll-runner/pull/1) - Make sure old files are not picked up and add regex to search log output

In this release 4 pull requests were closed.


v0.0.2

==> pytroll_runner-0.3.1.tar.gz: pytroll_runner-0.3.1/CHANGELOG.md <==
## Version 0.3.1 (2025/10/06)


### Pull Requests Merged

#### Features added

* [PR 55](https://github.com/pytroll/pytroll-runner/pull/55) - Add deploy to pypi

In this release 1 pull request was closed.


## Version 0.3.0 (2025/09/22)

### Issues Closed

* [Issue 25](https://github.com/pytroll/pytroll-runner/issues/25) - Erorr: Message is sent even if no match is successful when using the output-files-log-regex method

In this release 1 issue was closed.

### Pull Requests Merged

#### Bugs fixed

* [PR 53](https://github.com/pytroll/pytroll-runner/pull/53) - Randomise threaded test
* [PR 37](https://github.com/pytroll/pytroll-runner/pull/37) - Fix a typo in the logger.debug message issued by `run_and_publish()`

#### Features added

* [PR 54](https://github.com/pytroll/pytroll-runner/pull/54) - relicense to apache v2
* [PR 40](https://github.com/pytroll/pytroll-runner/pull/40) - Make the output from the subprocess print line by line

In this release 4 pull requests were closed.


## Version 0.2.0 (2025/04/28)


### Pull Requests Merged

#### Bugs fixed

* [PR 34](https://github.com/pytroll/pytroll-runner/pull/34) - Fix the bug #25 that a message is sent even when there is no match for the given regex
* [PR 33](https://github.com/pytroll/pytroll-runner/pull/33) - Support stderr

#### Features added

* [PR 31](https://github.com/pytroll/pytroll-runner/pull/31) - Allow passing metadata to the script
* [PR 29](https://github.com/pytroll/pytroll-runner/pull/29) - Migrate ci to newer python

In this release 4 pull requests were closed.


## Version 0.1.0 (2024/11/13)


### Pull Requests Merged

#### Features added

* [PR 19](https://github.com/pytroll/pytroll-runner/pull/19) - Add multiple threads capability
* [PR 8](https://github.com/pytroll/pytroll-runner/pull/8) - Add possibility to pass a message file
* [PR 7](https://github.com/pytroll/pytroll-runner/pull/7) - [pre-commit.ci] pre-commit autoupdate

In this release 3 pull requests were closed.


## Version 0.0.3 (2024/01/31)


### Pull Requests Merged

#### Bugs fixed

* [PR 5](https://github.com/pytroll/pytroll-runner/pull/5) - Fix starting publisher
* [PR 4](https://github.com/pytroll/pytroll-runner/pull/4) - Do not require "expected_files"
* [PR 3](https://github.com/pytroll/pytroll-runner/pull/3) - Fix premature closing of the subscriber

#### Features added

* [PR 1](https://github.com/pytroll/pytroll-runner/pull/1) - Make sure old files are not picked up and add regex to search log output

In this release 4 pull requests were closed.


v0.0.2
